# -*- coding: utf-8 -*-
from setuphelpers import *
import tarfile


def install():
    package_version = control.version.split("-")[0]
    filename = "firefox-%sesr.tar.bz2" % package_version

    run_notfatal("apt-get remove firefox -y")
    run_notfatal("apt-get remove firefox-esr -y")

    if type_debian():
        install_apt('libdbus-glib-1-2')
    else:
        install_yum('dbus-glib')

    extract_bz2(filename)
    killalltasks("firefox")
    if isdir("/opt/firefox-esr"):
        remove_tree("/opt/firefox-esr")
    copytree2("firefox", "/opt/firefox-esr")
    run("chown -R root:root /opt/firefox-esr")
    run("ln -sf /opt/firefox-esr/firefox /usr/bin/firefox")
    filecopyto("firefox.desktop", "/usr/share/applications/firefox.desktop")
    run("chown root:root /usr/share/applications/firefox.desktop")

    #To prevent security features warning
    if type_debian():
        if installed_softwares('apparmor')[0]['version'] >= '4.0':
            path = glob.glob('/home/*')[0]
            user = path.replace('/home/','')
            abi_version = Version(run('apt show apparmor').splitlines()[4].replace('Version: ',''),2)
            content = r'''
            # This profile allows everything and only exists to give the
    # application a name instead of having the label "unconfined"
    abi <abi/%s>,
    include <tunables/global>
    profile firefox-local
    /home/%s/bin/firefox/{firefox,firefox-bin,updater}
    flags=(unconfined) {
        userns,
        # Site-specific additions and overrides. See local/README for details.
        include if exists <local/firefox>
    }
    ''' % (abi_version,user)
            with open('/etc/apparmor.d/firefox-local','w') as f:
                f.write(content)
                f.close
            run('systemctl restart apparmor')


def uninstall():
    killalltasks("firefox")
    remove_file("/usr/share/applications/firefox.desktop")
    remove_tree("/opt/firefox-esr")


def extract_bz2(filename, path="."):
    with tarfile.open(filename, "r:bz2") as tar:
        tar.extractall(path)